==> types_boto3_support-1.35.71-py3-none-any.whl: types_boto3_support/paginator.py <==
"""
Type annotations for support service client paginators.

[Open documentation](https://youtype.github.io/types_boto3_docs/types_boto3_support/paginators/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_support.client import SupportClient
    from types_boto3_support.paginator import (
        DescribeCasesPaginator,
        DescribeCommunicationsPaginator,
    )

    session = Session()
    client: SupportClient = session.client("support")

    describe_cases_paginator: DescribeCasesPaginator = client.get_paginator("describe_cases")
    describe_communications_paginator: DescribeCommunicationsPaginator = client.get_paginator("describe_communications")
    ```

Copyright 2024 Vlad Emelianov
"""

import sys
from typing import Generic, Iterator, TypeVar

from botocore.paginate import PageIterator, Paginator

from .type_defs import (
    DescribeCasesRequestDescribeCasesPaginateTypeDef,
    DescribeCasesResponseTypeDef,
    DescribeCommunicationsRequestDescribeCommunicationsPaginateTypeDef,
    DescribeCommunicationsResponseTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = ("DescribeCasesPaginator", "DescribeCommunicationsPaginator")


_ItemTypeDef = TypeVar("_ItemTypeDef")


class _PageIterator(PageIterator, Generic[_ItemTypeDef]):
    def __iter__(self) -> Iterator[_ItemTypeDef]:
        """
        Proxy method to specify iterator item type.
        """


class DescribeCasesPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/support/paginator/DescribeCases.html#Support.Paginator.DescribeCases)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_support/paginators/#describecasespaginator)
    """

    def paginate(
        self, **kwargs: Unpack[DescribeCasesRequestDescribeCasesPaginateTypeDef]
    ) -> _PageIterator[DescribeCasesResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/support/paginator/DescribeCases.html#Support.Paginator.DescribeCases.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_support/paginators/#describecasespaginator)
        """


class DescribeCommunicationsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/support/paginator/DescribeCommunications.html#Support.Paginator.DescribeCommunications)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_support/paginators/#describecommunicationspaginator)
    """

    def paginate(
        self, **kwargs: Unpack[DescribeCommunicationsRequestDescribeCommunicationsPaginateTypeDef]
    ) -> _PageIterator[DescribeCommunicationsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/support/paginator/DescribeCommunications.html#Support.Paginator.DescribeCommunications.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_support/paginators/#describecommunicationspaginator)
        """

==> types_boto3_support-1.36.0-py3-none-any.whl: types_boto3_support/paginator.py <==
"""
Type annotations for support service client paginators.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_support/paginators/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_support.client import SupportClient
    from types_boto3_support.paginator import (
        DescribeCasesPaginator,
        DescribeCommunicationsPaginator,
    )

    session = Session()
    client: SupportClient = session.client("support")

    describe_cases_paginator: DescribeCasesPaginator = client.get_paginator("describe_cases")
    describe_communications_paginator: DescribeCommunicationsPaginator = client.get_paginator("describe_communications")
    ```

Copyright 2025 Vlad Emelianov
"""

from __future__ import annotations

import sys
from typing import TYPE_CHECKING

from botocore.paginate import PageIterator, Paginator

from .type_defs import (
    DescribeCasesRequestPaginateTypeDef,
    DescribeCasesResponseTypeDef,
    DescribeCommunicationsRequestPaginateTypeDef,
    DescribeCommunicationsResponseTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = ("DescribeCasesPaginator", "DescribeCommunicationsPaginator")


if TYPE_CHECKING:
    _DescribeCasesPaginatorBase = Paginator[DescribeCasesResponseTypeDef]
else:
    _DescribeCasesPaginatorBase = Paginator  # type: ignore[assignment]


class DescribeCasesPaginator(_DescribeCasesPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/support/paginator/DescribeCases.html#Support.Paginator.DescribeCases)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_support/paginators/#describecasespaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[DescribeCasesRequestPaginateTypeDef]
    ) -> PageIterator[DescribeCasesResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/support/paginator/DescribeCases.html#Support.Paginator.DescribeCases.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_support/paginators/#describecasespaginator)
        """


if TYPE_CHECKING:
    _DescribeCommunicationsPaginatorBase = Paginator[DescribeCommunicationsResponseTypeDef]
else:
    _DescribeCommunicationsPaginatorBase = Paginator  # type: ignore[assignment]


class DescribeCommunicationsPaginator(_DescribeCommunicationsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/support/paginator/DescribeCommunications.html#Support.Paginator.DescribeCommunications)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_support/paginators/#describecommunicationspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[DescribeCommunicationsRequestPaginateTypeDef]
    ) -> PageIterator[DescribeCommunicationsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/support/paginator/DescribeCommunications.html#Support.Paginator.DescribeCommunications.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_support/paginators/#describecommunicationspaginator)
        """
